<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use Illuminate\Http\Request;

class CategoriesController extends Controller
{
    public function index()
    {
        $rows = Category::where('parent_id', null)->orderByDesc('id')->get();
        return view('admin.categories.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.categories.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'name_ar' => 'required',
            'name_en' => 'required',
            'image' => 'required|image'
        ]);
        $category = new Category();
        $category['name->ar'] = $request['name_ar'];
        $category['name->en'] = $request['name_en'];
        $category['parent_id'] = null;
        $category->setImageAttribute();
        $category->save();
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('categories.index');
    }

    public function edit($id)
    {
        $row = Category::find($id);
        return view('admin.categories.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $request->validate([
            'name_ar' => 'required',
            'name_en' => 'required',
            'image' => 'image'
        ]);
        $category = Category::find($id);
        $category['name->ar'] = $request['name_ar'];
        $category['name->en'] = $request['name_en'];
        if ($request->hasFile('image')) {
            $category->setImageAttribute();
        }
        $category->update();
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('categories.index');

    }
    public function destroy($id){

        $row = Category::find($id);
        $row->deleteImage();

        Category::destroy($id);
        toast('تمت العملية بنجاح','success');
        return back();
    }
    public function show($id){
        $rows = Category::whereParentId($id)->orderByDesc('id')->get();

        return view('admin.sub_categories.index',compact('rows','id'));
    }
}
