<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\BanksResource;
use App\Http\Resources\PackagesResource;
use App\Http\Resources\UserResource;
use App\Models\Bank;
use App\Models\Package;
use App\Models\SubscriptionTransfer;
use App\Models\WorkerCategory;
use Carbon\Carbon;
use Illuminate\Http\Request;
use JWTAuth;

class SubscriptionController extends Controller
{

    public function subscription_packages(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $rows = Package::all();
        return PackagesResource::collection($rows)->additional(['value' => true]);

    }

    public function subscribe_package(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'package_id' => 'required',
            'transfer_type' => 'required|in:banking,online',
            'bank_id' => "required_if:transfer_type,banking",
            'image' => 'required_if:transfer_type,banking|image',
        ],[
            'image.required_if'=>\Lang::get('data.image_required_if')
        ]);
        if ($validator->passes()) {

            $transfer = new SubscriptionTransfer();
            $transfer['user_id'] = $user->id;
            $transfer['package_id'] = $request['package_id'];
            $transfer['transfer_type'] = $request['transfer_type'];
            $transfer['bank_id'] = $request['bank_id'];
            if ($request->hasFile('image')) $transfer->setImageAttribute();
            if ($request['transfer_type'] == 'online') {
                $transfer['status'] = 'approved';
            } else {
                $transfer['status'] = 'waiting';
            }
            $transfer->save();
            if ($transfer['transfer_type'] == 'online') {

                $user->subscription_id = $request['package_id'];
                $user->subscription_status = 'true';
                $user->subscription_date = Carbon::now();
                $user->update();
                return response()->json(['value' => true, 'data' => \Lang::get('data.subscription_done')]);
            } else {
                return response()->json(['value' => true, 'data' => \Lang::get('data.subscription_wait')]);

            }


        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }

    }

    public function banks()
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $rows = Bank::all();
        return BanksResource::collection($rows)->additional([
            'value' => true
        ]);

    }

}
