<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\WorkerImagesResource;
use App\Models\WorkerImage;
use Illuminate\Http\Request;
use JWTAuth;

class WorkerImagesController extends Controller
{
    public function index()
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $rows = WorkerImage::whereUserId($user->id)->get();
        return WorkerImagesResource::collection($rows)->additional([
            'value' => true
        ]);

    }

    public function store(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'images' => 'required'
        ]);
        if ($validator->passes()) {
            $i = 1;
            foreach ($request['images'] as $image) {

                $worker_image = new WorkerImage();
                $worker_image['user_id'] = $user->id;
                $file_name = $i . time() . '.' . $image->getClientOriginalExtension();
                $image->move(public_path('images/workers'), $file_name);
                $worker_image['image'] = $file_name;
                $worker_image->save();

                $i++;
            }


            $rows = WorkerImage::whereUserId($user->id)->get();
            return WorkerImagesResource::collection($rows)->additional([
                'value' => true
            ]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }


    }

    public function destroy($id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        WorkerImage::destroy($id);
        $rows = WorkerImage::whereUserId($user->id)->get();
        return WorkerImagesResource::collection($rows)->additional([
            'value' => true
        ]);
    }

    public function update($id, Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'image' => 'required|image'
        ]);
        if ($validator->passes()) {


            $worker_image = WorkerImage::find($id);
            if ($request->hasFile('image')) {

                $worker_image['user_id'] = $user->id;
                $file_name =time() . '.' . $request['image']->getClientOriginalExtension();
                $request['image']->move(public_path('images/workers'), $file_name);
                $worker_image['image'] = $file_name;
            }
            $worker_image->update();

            $rows = WorkerImage::whereUserId($user->id)->get();
            return WorkerImagesResource::collection($rows)->additional([
                'value' => true
            ]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }
}
